@@ -1,4 +1,5 @@
-from __future__ import annotations
+"Shared memory utils in python"
+__version__ = "0.0.1"
 
 from .posix import PosixSharedMemory, shm_open, shm_unlink
 from .mmap import MappedMemory, Flags as MapFlags, Protections as MapProtections
@@ -10,5 +11,7 @@ __all__ = [
     "shm_open",
     "shm_unlink",
     "MappedMemory",
+    "MapProtections",
+    "MapFlags",
     "RelativeView",
 ]
